class BaseExporter:
    def __init__(self, report: dict, output_path: str = None):
        self.report = report
        self.output_path = output_path

    def export(self):
        raise NotImplementedError
